@@ -115,22 +115,28 @@ api_info = {
 
     "UpdateServiceName":
         ApiInfo("POST", "/", {"Action": "UpdateServiceName", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "UpdateImageStorageTTL":
+        ApiInfo("POST", "/", {"Action": "UpdateImageStorageTTL", "Version": IMAGEX_API_VERSION}, {}, {}),
     "DescribeImageVolcCdnAccessLog":
         ApiInfo("POST", "/", {"Action": "DescribeImageVolcCdnAccessLog", "Version": IMAGEX_API_VERSION}, {}, {}),
 
     # 其他 API
-    "GetImageOCR":
-        ApiInfo("POST", "/", {"Action": "GetImageOCR", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageOCRV2":
+        ApiInfo("POST", "/", {"Action": "GetImageOCRV2", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetImageQuality":
         ApiInfo("POST", "/", {"Action": "GetImageQuality", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetImageEraseModels":
         ApiInfo("GET", "/", {"Action": "GetImageEraseModels", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetImageEnhanceResult":
         ApiInfo("POST", "/", {"Action": "GetImageEnhanceResult", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageEnhanceResultWithData":
+        ApiInfo("POST", "/", {"Action": "GetImageEnhanceResultWithData", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetImageBgFillResult":
         ApiInfo("POST", "/", {"Action": "GetImageBgFillResult", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetImageDuplicateDetection":
         ApiInfo("POST", "/", {"Action": "GetImageDuplicateDetection", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetDedupTaskStatus":
+        ApiInfo("GET", "/", {"Action": "GetImageDuplicateDetection", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetDenoisingImage":
         ApiInfo("POST", "/", {"Action": "GetDenoisingImage", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetSegmentImage":
@@ -153,4 +159,6 @@ api_info = {
         ApiInfo("POST", "/", {"Action": "CreateImageHmExtract", "Version": IMAGEX_API_VERSION}, {}, {}),
     "GetImageEraseResult":
         ApiInfo("POST", "/", {"Action": "GetImageEraseResult", "Version": IMAGEX_API_VERSION}, {}, {}),
+    "GetImageStyleResult":
+        ApiInfo("POST", "/", {"Action": "GetImageStyleResult", "Version": IMAGEX_API_VERSION}, {}, {}),
 }
