@@ -90,6 +90,14 @@ OPEN_KAFKA_CONSUMER = "/OpenKafkaConsumer"
 CLOSE_KAFKA_CONSUMER = "/CloseKafkaConsumer"
 DESCRIBE_KAFKA_CONSUMER = "/DescribeKafkaConsumer"
 
+CREATE_CONSUMER_GROUP = "/CreateConsumerGroup"
+DELETE_CONSUMER_GROUP = "/DeleteConsumerGroup"
+MODIFY_CONSUMER_GROUP = "/ModifyConsumerGroup"
+DESCRIBE_CONSUMER_GROUPS = "/DescribeConsumerGroups"
+CONSUMER_HEARTBEAT = "/ConsumerHeartbeat"
+MODIFY_CHECKPOINT = "/ModifyCheckPoint"
+DESCRIBE_CHECKPOINT = "/DescribeCheckPoint"
+
 # TLS API fields
 DATA = "Data"
 
@@ -112,6 +120,11 @@ TOPIC_NAME = "TopicName"
 TTL = "Ttl"
 SHARD_COUNT = "ShardCount"
 TOPICS = "Topics"
+AUTO_SPLIT = "AutoSplit"
+MAX_SPLIT_SHARD = "MaxSplitShard"
+ENABLE_TRACKING = "EnableTracking"
+TAGS = "Tags"
+LOG_PUBLIC_IP = "LogPublicIP"
 
 FULL_TEXT = "FullText"
 KEY_VALUE = "KeyValue"
@@ -213,6 +226,13 @@ HASH_KEY = "HashKey"
 SHARD_HASH_KEY = "ShardHashKey"
 ENABLE_RAW_LOG = "EnableRawLog"
 FIELDS = "Fields"
+PLUGIN = "Plugin"
+ADVANCED = "Advanced"
+CLOSE_INACTIVE = "CloseInactive"
+CLOSE_TIMEOUT = "CloseTimeout"
+CLOSE_REMOVED = "CloseRemoved"
+CLOSE_RENAMED = "CloseRenamed"
+CLOSE_EOF = "CloseEOF"
 
 ALARM_NOTIFY_GROUP_ID = "AlarmNotifyGroupId"
 ALARM_NOTIFY_GROUP_NAME = "AlarmNotifyGroupName"
@@ -221,6 +241,7 @@ TRIGGER = "Trigger"
 RECOVERY = "Recovery"
 RECEIVERS = "Receivers"
 RECEIVER_NAME = "ReceiverName"
+IAM_PROJECT_NAME = "IamProjectName"
 ALARM_NOTIFY_GROUPS = "AlarmNotifyGroups"
 ALARM_ID = "AlarmId"
 ALARM_NAME = "AlarmName"
@@ -241,6 +262,32 @@ RECEIVER_TYPE = "ReceiverType"
 RECEIVER_NAMES = "ReceiverNames"
 RECEIVER_CHANNELS = "ReceiverChannels"
 WEBHOOK = "Webhook"
+ALARM_PERIOD_DETAIL = "AlarmPeriodDetail"
+SMS = "SMS"
+PHONE = "Phone"
+EMAIL = "Email"
+GENERAL_WEBHOOK = "GeneralWebhook"
 
 ALLOW_CONSUME = "AllowConsume"
 CONSUME_TOPIC = "ConsumeTopic"
+
+PROJECT_ID_UPPERCASE = "ProjectID"
+CONSUMER_GROUP_NAME = "ConsumerGroupName"
+TOPIC_ID_LIST = "TopicIDList"
+HEARTBEAT_TTL = "HeartbeatTTL"
+ORDERED_CONSUME = "OrderedConsume"
+CONSUMER_GROUPS = "ConsumerGroups"
+CONSUMER_NAME = "ConsumerName"
+TOPIC_ID_UPPERCASE = "TopicID"
+SHARD_ID_UPPERCASE = "ShardID"
+CHECKPOINT = "Checkpoint"
+UPDATE_TIME = "UpdateTime"
+CONSUMER = "Consumer"
+CONSUME_FROM = "ConsumeFrom"
+HEARTBEAT_INTERVAL_IN_SECOND = "HeartbeatIntervalInSecond"
+DATA_FETCH_INTERVAL_IN_MILLISECOND = "DataFetchIntervalInMillisecond"
+FLUSH_CHECKPOINT_INTERVAL_IN_SECOND = "FlushCheckpointIntervalInSecond"
+MAX_FETCH_LOG_GROUP_COUNT = "MaxFetchLogGroupCount"
+ERROR_CONSUMER_GROUP_ALREADY_EXISTS = "ConsumerGroupAlreadyExists"
+ERROR_CONSUMER_HEARTBEAT_EXPIRED = "ConsumerHeartbeatExpired"
+STOP_TIMEOUT = "StopTimeout"
