@@ -850,3 +850,56 @@ class DescribeKafkaConsumerResponse(TLSResponse):
         :rtype: str
         """
         return self.consume_topic
+
+
+class CreateConsumerGroupResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(CreateConsumerGroupResponse, self).__init__(response)
+
+
+class DeleteConsumerGroupResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(DeleteConsumerGroupResponse, self).__init__(response)
+
+
+class ModifyConsumerGroupResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(ModifyConsumerGroupResponse, self).__init__(response)
+
+
+class DescribeConsumerGroupsResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(DescribeConsumerGroupsResponse, self).__init__(response)
+
+        self.consumer_groups = []
+        consumer_groups = self.response[CONSUMER_GROUPS]
+
+        for i in range(len(consumer_groups)):
+            self.consumer_groups.append(ConsumerGroup.set_attributes(data=consumer_groups[i]))
+
+
+class ConsumerHeartbeatResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(ConsumerHeartbeatResponse, self).__init__(response)
+
+        self.shards = []
+        shards = self.response.get(SHARDS)
+
+        if shards is not None:
+            for i in range(len(shards)):
+                self.shards.append(ConsumeShard.set_attributes(data=shards[i]))
+
+
+class ModifyCheckpointResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(ModifyCheckpointResponse, self).__init__(response)
+
+
+class DescribeCheckpointResponse(TLSResponse):
+    def __init__(self, response: Response):
+        super(DescribeCheckpointResponse, self).__init__(response)
+
+        self.shard_id = self.response.get(SHARD_ID_UPPERCASE)
+        self.checkpoint = self.response.get(CHECKPOINT)
+        self.update_time = self.response.get(UPDATE_TIME)
+        self.consumer = self.response.get(CONSUMER)
