@@ -8,11 +8,13 @@ class Function:
         return {'Name': 'Snapshot', 'Input': {'SnapshotTime': snapshot_time}}
 
     @staticmethod
-    def get_add_option_info_func(title, tags, description):
-        return {'Name': 'AddOptionInfo', 'Input': {'Title': title, 'Tags': tags, 'Description': description}}
+    def get_add_option_info_func(title, tags, description, classification_id, is_hls_index_only=False):
+        return {'Name': 'AddOptionInfo',
+                'Input': {'Title': title, 'Tags': tags, 'Description': description,
+                          'ClassificationId': classification_id, "IsHlsIndexOnly": is_hls_index_only}}
 
     @staticmethod
-    def get_add_option_info_func(title, tags, description, category, record_type, format_input):
+    def get_add_material_option_info_func(title, tags, description, category, record_type, format_input):
         return {'Name': 'AddOptionInfo',
                 'Input': {'Title': title, 'Tags': tags, 'Description': description, 'Category': category,
                           'RecordType': record_type, 'Format': format_input}}
